@@ -2,7 +2,7 @@
 
 package File::Chunk::Format::Hex;
 {
-  $File::Chunk::Format::Hex::VERSION = '0.002';
+  $File::Chunk::Format::Hex::VERSION = '0.003';
 }
 BEGIN {
   $File::Chunk::Format::Hex::AUTHORITY = 'cpan:DHARDISON';
@@ -11,21 +11,27 @@ use Moose;
 use namespace::autoclean;
 
 use MooseX::Params::Validate;
-use MooseX::Types::Path::Class 'Dir';
+use MooseX::Types::Path::Class 'File';
 
 use Path::Class::Rule;
 
-with 'File::Chunk::Format';
+with 'File::Chunk::Format::Regexp';
 
-sub find_chunk_files {
+sub chunk_regexp { qr/^[[:xdigit:]]{8}\.chunk$/ }
+
+around decode_chunk_filename => sub {
+    my ($method, $self, @args) = @_;
+    hex($self->$method(@args));
+};
+
+sub encode_chunk_filename {
     my $self = shift;
-    my ($dir) = pos_validated_list( \@_, { isa => Dir, coerce => 1 } );
+    my ($i) = pos_validated_list(\@_, { isa => 'Int' });
 
-    my $rules = Path::Class::Rule->new->skip_vcs->file->name(qr/^[[:xdigit:]]{8}\.chunk$/);
-
-    return $rules->iter( $dir, { depthfirst => 1 } );
+    return sprintf "%.8x.chunk", $i; 
 }
 
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -40,7 +46,7 @@ File::Chunk::Format::Hex - Chunk files stored in $X.chunk where $X is an eight "
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
@@ -48,7 +54,7 @@ Dylan William Hardison <dylan@hardison.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc.
+This software is copyright (c) 2013 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
